@@ -39,8 +39,8 @@ static void init_sent_message_list(void);
 void pool_init_session_context(POOL_CONNECTION *frontend, POOL_CONNECTION_POOL *backend)
 {
 	session_context = &session_context_d;
+	ProcessInfo *process_info;
 	int node_id;
-	int i;
 
 	/* Get Process context */
 	session_context->process_context = pool_get_process_context();
@@ -66,7 +66,14 @@ void pool_init_session_context(POOL_CONNECTION *frontend, POOL_CONNECTION_POOL *
 	/* Create memory context */
 	session_context->memory_context = pool_memory_create(PREPARE_BLOCK_SIZE);
 
-	/* Choose load balancing node if neccessary */
+	process_info = pool_get_my_process_info();
+	if (!process_info)
+	{
+		pool_error("pool_init_session_context: pool_get_my_process_info failed");
+		return;
+	}
+
+	/* Choose load balancing node if necessary */
 	if (pool_config->load_balance_mode)
 	{
 		node_id = select_load_balancing_node();
@@ -76,15 +83,10 @@ void pool_init_session_context(POOL_CONNECTION *frontend, POOL_CONNECTION_POOL *
 		node_id = STREAM? PRIMARY_NODE_ID: MASTER_NODE_ID;
 	}
 
-	session_context->load_balance_node_id = node_id;
+	session_context->load_balance_node_id = 
+		process_info->connection_info->load_balancing_node = node_id;
 
-	for (i=0;i<NUM_BACKENDS;i++)
-	{
-		pool_coninfo(session_context->process_context->proc_id,
-					 pool_pool_index(), i)->load_balancing_node = node_id;
-	}
-
-	pool_debug("selected load balancing node: %d", node_id);
+	pool_debug("selected load balancing node: %d", backend->info->load_balancing_node);
 
 	/* Unset query is in progress */
 	pool_unset_query_in_progress();
@@ -107,7 +109,7 @@ void pool_init_session_context(POOL_CONNECTION *frontend, POOL_CONNECTION_POOL *
 	/* Backends have not ignored messages yet */
 	pool_unset_ignore_till_sync();
 
-	/* Initialize where to send map for PREPARE statemets */
+	/* Initialize where to send map for PREPARE statements */
 #ifdef NOT_USED
 	memset(&session_context->prep_where, 0, sizeof(session_context->prep_where));
 	session_context->prep_where.nelem = POOL_MAX_PREPARED_STATEMENTS;
@@ -963,50 +965,3 @@ bool can_query_context_destroy(POOL_QUERY_CONTEXT *qc)
 
 	return true;
 }
-
-/*
- * Set protocol major version number
- */
-void pool_set_major_version(int major)
-{
-	if (session_context)
-	{
-		session_context->major = major; 
-	}
-}
-
-/*
- * Get protocol major version number
- */
-int pool_get_major_version(void)
-{
-	if (session_context)
-	{
-		return session_context->major;
-	}
-	return PROTO_MAJOR_V3;
-}
-
-/*
- * Set protocol minor version number
- */
-void pool_set_minor_version(int minor)
-{
-	if (session_context)
-	{
-		session_context->minor = minor; 
-	}
-}
-
-/*
- * Get protocol minor version number
- */
-int pool_get_minor_version(void)
-{
-	if (session_context)
-	{
-		return session_context->minor;
-	}
-	return 0;
-}
-
